@@ -39,19 +39,19 @@
 #' @examples
 #' \dontrun{
 #' x <- election_results(ID = 382037)
-#' 
+#'
 #' y <- election_results()
-#' 
+#'
 #' z <- election_results(calculate_percent = TRUE, constit_details = TRUE)
-#' 
+#'
 #' w <- election_results(ID = 730039, all_data = TRUE)
 #' }
-#' 
+#'
 election_results <- function(ID = NULL, all_data = FALSE,
                              calculate_percent = FALSE,
                              constit_details = FALSE,
                              extra_args = NULL, tidy = TRUE,
-                             tidy_style = "snake_case", verbose = TRUE) {
+                             tidy_style = "snake", verbose = TRUE) {
   id_query <- ifelse(is.null(ID), "", paste0("electionId=", ID))
 
   baseurl <- paste0(url_util, "electionresults.json?")
@@ -67,7 +67,7 @@ election_results <- function(ID = NULL, all_data = FALSE,
 
   jpage <- floor(elect$result$totalResults / 100)
 
-  query <- paste0(baseurl, id_query, extra_args, "&_pageSize=100&_page=")
+  query <- paste0(baseurl, id_query, extra_args)
 
   df <- loop_query(query, jpage, verbose) # in utils-loop.R
 
